==> haskell-drbg-0.5.5-102-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-drbg.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 DRBG
version:              0.5.5
visibility:           public
id:                   DRBG-0.5.5-LgzdeufXhcCYM9IIxNO3Q
key:                  DRBG-0.5.5-LgzdeufXhcCYM9IIxNO3Q
license:              BSD-3-Clause
maintainer:           Thomas DuBuisson
author:               Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability:            stable
synopsis:
    Deterministic random bit generator (aka RNG, PRNG) based
    HMACs, Hashes, and Ciphers.

description:          Cryptographically secure RNGs
category:             Cryptography
abi:                  0c07ae927dd01eb5833dd96d577468fb
exposed:              True
exposed-modules:
    Crypto.Random.DRBG Crypto.Random.DRBG.CTR Crypto.Random.DRBG.HMAC
    Crypto.Random.DRBG.Hash Crypto.Random.DRBG.Types

hidden-modules:       Crypto.Random.DRBG.HashDF
import-dirs:          /usr/lib/ghc-8.10.2/site-local/DRBG-0.5.5
library-dirs:         /usr/lib/ghc-8.10.2/site-local/DRBG-0.5.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/DRBG-0.5.5
hs-libraries:         HSDRBG-0.5.5-LgzdeufXhcCYM9IIxNO3Q
depends:
    base-4.14.1.0 bytestring-0.10.10.0
    cereal-0.5.8.1-56yg04wGStN22upOSM9put
    cipher-aes128-0.7.0.5-Eq8xFk9tay9Imx731U7mnG
    crypto-api-0.13.3-3crMriq1Cru2GHNhVUzp6Y
    cryptohash-cryptoapi-0.1.4-HjG5qnblMTRK7G9ICPn08Y
    entropy-0.4.1.6-9PryOfo5UGm2sncsbscV7i mtl-2.2.2
    parallel-3.2.2.0-HTf2o2horULDwL7cXUB9uv
    prettyclass-1.0.0.0-FKRh4s9QhhBDCk8hIvEict
    tagged-0.8.6-6ynGuqiqWewDmeFAuVgKQe

haddock-interfaces:   /usr/share/doc/haskell-drbg/html/DRBG.haddock
haddock-html:         /usr/share/doc/haskell-drbg/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-drbg-0.5.5-104-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-drbg.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 DRBG
version:              0.5.5
visibility:           public
id:                   DRBG-0.5.5-5vNwodDqhzOFisSx6er6bG
key:                  DRBG-0.5.5-5vNwodDqhzOFisSx6er6bG
license:              BSD-3-Clause
maintainer:           Thomas DuBuisson
author:               Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability:            stable
synopsis:
    Deterministic random bit generator (aka RNG, PRNG) based
    HMACs, Hashes, and Ciphers.

description:          Cryptographically secure RNGs
category:             Cryptography
abi:                  ea1586b5009105e827788bb95fa4c771
exposed:              True
exposed-modules:
    Crypto.Random.DRBG Crypto.Random.DRBG.CTR Crypto.Random.DRBG.HMAC
    Crypto.Random.DRBG.Hash Crypto.Random.DRBG.Types

hidden-modules:       Crypto.Random.DRBG.HashDF
import-dirs:          /usr/lib/ghc-8.10.2/site-local/DRBG-0.5.5
library-dirs:         /usr/lib/ghc-8.10.2/site-local/DRBG-0.5.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/DRBG-0.5.5
hs-libraries:         HSDRBG-0.5.5-5vNwodDqhzOFisSx6er6bG
depends:
    base-4.14.1.0 bytestring-0.10.10.0
    cereal-0.5.8.1-56yg04wGStN22upOSM9put
    cipher-aes128-0.7.0.5-Eq8xFk9tay9Imx731U7mnG
    crypto-api-0.13.3-3crMriq1Cru2GHNhVUzp6Y
    cryptohash-cryptoapi-0.1.4-HjG5qnblMTRK7G9ICPn08Y
    entropy-0.4.1.6-9PryOfo5UGm2sncsbscV7i mtl-2.2.2
    parallel-3.2.2.0-HTf2o2horULDwL7cXUB9uv
    prettyclass-1.0.0.0-FKRh4s9QhhBDCk8hIvEict
    tagged-0.8.6-6ynGuqiqWewDmeFAuVgKQe

haddock-interfaces:   /usr/share/doc/haskell-drbg/html/DRBG.haddock
haddock-html:         /usr/share/doc/haskell-drbg/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
